@@ -1,6 +1,87 @@
 #include "ruby_libxml.h"
 #include "ruby_xml.h"
 
+static struct st_table *private_pointers;
+
+static int registered = 0;   // Constant to track what nodes have been registered
+
+void rxml_register(void *xnode, VALUE value) {
+  st_insert(private_pointers, (st_data_t)xnode, (st_data_t)value);
+}
+
+void rxml_register_node(xmlNodePtr xnode, VALUE value) {
+  if (rxml_lookup_node(xnode) == Qnil) {
+    xnode->_private = &registered;
+    rxml_register(xnode, value);
+  }
+}
+
+void rxml_register_doc(xmlDocPtr xdoc, VALUE value) {
+  if (rxml_lookup_doc(xdoc) == Qnil) {
+    xdoc->_private = &registered;
+    rxml_register(xdoc, value);
+  }
+}
+
+void rxml_register_dtd(xmlDtdPtr xdtd, VALUE value) {
+  if (rxml_lookup_dtd(xdtd) == Qnil) {
+    xdtd->_private = &registered;
+    rxml_register(xdtd, value);
+  }
+}
+
+void rxml_unregister(void *xnode) {
+  st_delete(private_pointers, (st_data_t*)&xnode, NULL);
+}
+
+void rxml_unregister_node(xmlNodePtr xnode) {
+  if (xnode->_private == &registered) {
+    xnode->_private = NULL;
+    rxml_unregister(xnode);
+  }
+}
+
+void rxml_unregister_doc(xmlDocPtr xdoc) {
+  if (xdoc->_private == &registered) {
+    xdoc->_private = NULL;
+    rxml_unregister(xdoc);
+  }
+}
+
+void rxml_unregister_dtd(xmlDtdPtr xdtd) {
+  if (xdtd->_private == &registered) {
+    xdtd->_private = NULL;
+    rxml_unregister(xdtd);
+  }
+}
+
+VALUE rxml_lookup(void *pointer) {
+  st_data_t result = 0;
+  int ret = st_lookup(private_pointers, (st_data_t)pointer, &result);
+  return ret ? (VALUE)result : Qnil;
+}
+
+VALUE rxml_lookup_node(xmlNodePtr xnode) {
+  if (!xnode || xnode->_private != &registered)
+    return Qnil;
+
+  return rxml_lookup(xnode);
+}
+
+VALUE rxml_lookup_doc(xmlDocPtr xdoc) {
+  if (!xdoc || xdoc->_private != &registered)
+    return Qnil;
+
+  return rxml_lookup(xdoc);
+}
+
+VALUE rxml_lookup_dtd(xmlDtdPtr xdtd) {
+  if (!xdtd || xdtd->_private != &registered)
+    return Qnil;
+
+  return rxml_lookup(xdtd);
+}
+
 VALUE mXML;
 
 /*
@@ -353,10 +434,10 @@ static VALUE rxml_debug_entities_get(VALUE klass)
  * Enable or disable included-entity debugging.
  * (Requires Libxml to be compiled with debugging support)
  */
-static VALUE rxml_debug_entities_set(VALUE klass, VALUE bool)
+static VALUE rxml_debug_entities_set(VALUE klass, VALUE value)
 {
 #ifdef LIBXML_DEBUG_ENABLED
-  if (TYPE(bool) == T_FALSE)
+  if (value == Qfalse)
   {
     xmlParserDebugEntities = 0;
     return(Qfalse);
@@ -391,14 +472,14 @@ static VALUE rxml_default_keep_blanks_get(VALUE klass)
  *
  * Controls whether parsers retain whitespace by default.
  */
-static VALUE rxml_default_keep_blanks_set(VALUE klass, VALUE bool)
+static VALUE rxml_default_keep_blanks_set(VALUE klass, VALUE value)
 {
-  if (TYPE(bool) == T_FALSE)
+  if (value == Qfalse)
   {
     xmlKeepBlanksDefaultValue = 0;
     return (Qfalse);
   }
-  else if (TYPE(bool) == T_TRUE)
+  else if (value == Qtrue)
   {
     xmlKeepBlanksDefaultValue = 1;
     return (Qtrue);
@@ -429,9 +510,9 @@ static VALUE rxml_default_load_external_dtd_get(VALUE klass)
  *
  * Controls whether parsers load external DTDs by default.
  */
-static VALUE rxml_default_load_external_dtd_set(VALUE klass, VALUE bool)
+static VALUE rxml_default_load_external_dtd_set(VALUE klass, VALUE value)
 {
-  if (bool == Qfalse)
+  if (value == Qfalse)
   {
     xmlLoadExtDtdDefaultValue = 0;
     return (Qfalse);
@@ -463,9 +544,9 @@ static VALUE rxml_default_line_numbers_get(VALUE klass)
  *
  * Controls whether parsers retain line-numbers by default.
  */
-static VALUE rxml_default_line_numbers_set(VALUE klass, VALUE bool)
+static VALUE rxml_default_line_numbers_set(VALUE klass, VALUE value)
 {
-  if (TYPE(bool) == T_FALSE)
+  if (value == Qfalse)
   {
     xmlLineNumbersDefault(0);
     return (Qfalse);
@@ -534,9 +615,9 @@ static VALUE rxml_default_pedantic_parser_get(VALUE klass)
  *
  * Controls whether parsers are pedantic by default.
  */
-static VALUE rxml_default_pedantic_parser_set(VALUE klass, VALUE bool)
+static VALUE rxml_default_pedantic_parser_set(VALUE klass, VALUE value)
 {
-  if (TYPE(bool) == T_FALSE)
+  if (value == Qfalse)
   {
     xmlPedanticParserDefault(0);
     return (Qfalse);
@@ -570,9 +651,9 @@ static VALUE rxml_default_substitute_entities_get(VALUE klass)
  * Controls whether parsers perform inline entity substitution
  * (for external entities) by default.
  */
-static VALUE rxml_default_substitute_entities_set(VALUE klass, VALUE bool)
+static VALUE rxml_default_substitute_entities_set(VALUE klass, VALUE value)
 {
-  if (bool == Qfalse)
+  if (value == Qfalse)
   {
     xmlSubstituteEntitiesDefault(0);
     return (Qfalse);
@@ -609,7 +690,7 @@ static VALUE rxml_default_tree_indent_string_get(VALUE klass)
 static VALUE rxml_default_tree_indent_string_set(VALUE klass, VALUE string)
 {
   Check_Type(string, T_STRING);
-  xmlTreeIndentString = xmlStrdup((xmlChar *)StringValuePtr(string));
+  xmlTreeIndentString = (const char *)xmlStrdup((xmlChar *)StringValuePtr(string));
   return (string);
 }
 
@@ -633,9 +714,9 @@ static VALUE rxml_default_validity_checking_get(VALUE klass)
  *
  * Controls whether parsers perform XML validation by default.
  */
-static VALUE rxml_default_validity_checking_set(VALUE klass, VALUE bool)
+static VALUE rxml_default_validity_checking_set(VALUE klass, VALUE value)
 {
-  if (TYPE(bool) == T_FALSE)
+  if (value == Qfalse)
   {
     xmlDoValidityCheckingDefaultValue = 0;
     return (Qfalse);
@@ -667,9 +748,9 @@ static VALUE rxml_default_warnings_get(VALUE klass)
  *
  * Controls whether parsers output warnings by default.
  */
-static VALUE rxml_default_warnings_set(VALUE klass, VALUE bool)
+static VALUE rxml_default_warnings_set(VALUE klass, VALUE value)
 {
-  if (TYPE(bool) == T_FALSE)
+  if (value == Qfalse)
   {
     xmlGetWarningsDefaultValue = 0;
     return (Qfalse);
@@ -774,14 +855,14 @@ static VALUE rxml_indent_tree_output_get(VALUE klass)
  * Controls whether XML output will be indented
  * (using the string supplied to +default_indent_tree_string+)
  */
-static VALUE rxml_indent_tree_output_set(VALUE klass, VALUE bool)
+static VALUE rxml_indent_tree_output_set(VALUE klass, VALUE value)
 {
-  if (TYPE(bool) == T_TRUE)
+  if (value == Qtrue)
   {
     xmlIndentTreeOutput = 1;
     return (Qtrue);
   }
-  else if (TYPE(bool) == T_FALSE)
+  else if (value == Qfalse)
   {
     xmlIndentTreeOutput = 0;
     return (Qfalse);
@@ -834,6 +915,9 @@ static VALUE rxml_memory_used(VALUE self)
 
 void rxml_init_xml(void)
 {
+  /* Create a hashtable suitable for pointer keys */
+  private_pointers = st_init_numtable();
+
   mXML = rb_define_module_under(mLibXML, "XML");
 
   /* Constants */
