@@ -62,8 +62,7 @@ void rxml_document_mark_node_list(xmlNodePtr xnode)
   while (xnode != NULL)
   {
     rxml_document_mark_node_list(xnode->children);
-    if (xnode->_private)
-      rb_gc_mark((VALUE) xnode->_private);
+    rxml_node_mark(xnode);
     xnode = xnode->next;
   }
 }
@@ -76,25 +75,18 @@ void rxml_document_mark(xmlDocPtr xdoc)
 
 void rxml_document_free(xmlDocPtr xdoc)
 {
-  xdoc->_private = NULL;
+  rxml_unregister_doc(xdoc);
   xmlFreeDoc(xdoc);
 }
 
 VALUE rxml_document_wrap(xmlDocPtr xdoc)
 {
-  VALUE result;
+  VALUE result = rxml_lookup_doc(xdoc);
 
-  // This node is already wrapped
-  if (xdoc->_private != NULL)
-  {
-    result = (VALUE) xdoc->_private;
-  }
-  else
-  {
+  if (result == Qnil) {
     result = Data_Wrap_Struct(cXMLDocument, rxml_document_mark, rxml_document_free, xdoc);
-    xdoc->_private = (void*) result;
+    rxml_register_doc(xdoc, result);
   }
-
   return result;
 }
 
@@ -136,7 +128,7 @@ static VALUE rxml_document_initialize(int argc, VALUE *argv, VALUE self)
 
   Check_Type(xmlver, T_STRING);
   xdoc = xmlNewDoc((xmlChar*) StringValuePtr(xmlver));
-  xdoc->_private = (void*) self;
+  rxml_register_doc(xdoc, self);
   DATA_PTR(self) = xdoc;
 
   return self;
@@ -196,14 +188,13 @@ static VALUE
 rxml_document_canonicalize(int argc, VALUE *argv, VALUE self)
 {
   VALUE result = Qnil;
-  int length;
   xmlDocPtr xdoc;
   xmlChar *buffer = NULL;
   VALUE option_hash = Qnil;
   VALUE o_nodes = Qnil;
 
   // :comments option
-  VALUE comments = Qfalse;
+  int comments = 0;
   // :mode option
   int c14n_mode = XML_C14N_1_0;
   // :inclusive_ns_prefixes option (ARRAY)
@@ -251,7 +242,7 @@ rxml_document_canonicalize(int argc, VALUE *argv, VALUE self)
       int i;
       int p = 0; //pointer array index
       VALUE *list_in = NULL;
-      int list_size = 0;
+      long list_size = 0;
 
 	  Check_Type(o_i_ns_prefixes, T_ARRAY);
       list_in = RARRAY_PTR(o_i_ns_prefixes);
@@ -288,7 +279,7 @@ rxml_document_canonicalize(int argc, VALUE *argv, VALUE self)
       int i;
       int p = 0; // index of pointer array
       VALUE * list_in = NULL;
-      int node_list_size = 0;
+      long node_list_size = 0;
 
 	  if (CLASS_OF(o_nodes) == cXMLXPathObject)
 	  {
@@ -317,24 +308,22 @@ rxml_document_canonicalize(int argc, VALUE *argv, VALUE self)
       // Need to set values in nodeset struct
       nodeset.nodeNr = (node_list_size > C14N_NODESET_LIMIT ?
                         C14N_NODESET_LIMIT :
-                        node_list_size);
+                        (int)node_list_size);
       nodeset.nodeTab = node_ptr_array;
     }
   }//option_hash
 
   Data_Get_Struct(self, xmlDoc, xdoc);
-  length = xmlC14NDocDumpMemory(
-    xdoc,
-    (nodeset.nodeNr == 0 ? NULL : &nodeset),
-    c14n_mode,
-    inc_ns_prefixes_ptr,
-    comments,
-    &buffer
-  );
+  xmlC14NDocDumpMemory(xdoc,
+                       (nodeset.nodeNr == 0 ? NULL : &nodeset),
+                       c14n_mode,
+                       inc_ns_prefixes_ptr,
+                       comments,
+                       &buffer);
 
   if (buffer)
   {
-    result = rxml_new_cstr((const char*) buffer, NULL);
+    result = rxml_new_cstr( buffer, NULL);
     xmlFree(buffer);
   }
 
@@ -508,12 +497,10 @@ static VALUE rxml_document_encoding_get(VALUE self)
 static VALUE rxml_document_rb_encoding_get(VALUE self)
 {
   xmlDocPtr xdoc;
-  const char *xencoding;
   rb_encoding* rbencoding;
   Data_Get_Struct(self, xmlDoc, xdoc);
 
-  xencoding = (const char*)xdoc->encoding;
-  rbencoding = rxml_xml_encoding_to_rb_encoding(mXMLEncoding, xmlParseCharEncoding(xencoding));
+  rbencoding = rxml_xml_encoding_to_rb_encoding(mXMLEncoding, xmlParseCharEncoding((const char*)xdoc->encoding));
   return rb_enc_from_encoding(rbencoding);
 }
 #endif
@@ -732,7 +719,6 @@ static VALUE rxml_document_prev_q(VALUE self)
 static VALUE rxml_document_root_get(VALUE self)
 {
   xmlDocPtr xdoc;
-
   xmlNodePtr root;
 
   Data_Get_Struct(self, xmlDoc, xdoc);
@@ -753,7 +739,7 @@ static VALUE rxml_document_root_get(VALUE self)
 static VALUE rxml_document_root_set(VALUE self, VALUE node)
 {
   xmlDocPtr xdoc;
-  xmlNodePtr xroot, xnode;
+  xmlNodePtr xnode;
 
   if (rb_obj_is_kind_of(node, cXMLNode) == Qfalse)
     rb_raise(rb_eTypeError, "must pass an XML::Node type object");
@@ -764,7 +750,7 @@ static VALUE rxml_document_root_set(VALUE self, VALUE node)
   if (xnode->doc != NULL && xnode->doc != xdoc)
     rb_raise(eXMLError, "Nodes belong to different documents.  You must first import the node by calling XML::Document.import");
 
-  xroot = xmlDocSetRootElement(xdoc, xnode);
+  xmlDocSetRootElement(xdoc, xnode);
   return node;
 }
 
@@ -792,7 +778,7 @@ static VALUE rxml_document_save(int argc, VALUE *argv, VALUE self)
   xmlDocPtr xdoc;
   int indent = 1;
   const char *xfilename;
-  const char *xencoding;
+  const xmlChar *xencoding;
   int length;
 
   rb_scan_args(argc, argv, "11", &filename, &options);
@@ -815,13 +801,13 @@ static VALUE rxml_document_save(int argc, VALUE *argv, VALUE self)
 
     if (rencoding != Qnil)
     {
-      xencoding = xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
+      xencoding = (const xmlChar*)xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
       if (!xencoding)
         rb_raise(rb_eArgError, "Unknown encoding value: %d", NUM2INT(rencoding));
     }
   }
 
-  length = xmlSaveFormatFileEnc(xfilename, xdoc, xencoding, indent);
+  length = xmlSaveFormatFileEnc(xfilename, xdoc, (const char*)xencoding, indent);
 
   if (length == -1)
     rxml_raise(&xmlLastError);
@@ -869,7 +855,7 @@ static VALUE rxml_document_to_s(int argc, VALUE *argv, VALUE self)
   VALUE options = Qnil;
   xmlDocPtr xdoc;
   int indent = 1;
-  const char *xencoding = "UTF-8";
+  const xmlChar *xencoding = (const xmlChar*) "UTF-8";
   xmlChar *buffer;
   int length;
 
@@ -887,16 +873,16 @@ static VALUE rxml_document_to_s(int argc, VALUE *argv, VALUE self)
 
     if (rencoding != Qnil)
     {
-      xencoding = xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
+      xencoding = (const xmlChar*)xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
       if (!xencoding)
         rb_raise(rb_eArgError, "Unknown encoding value: %d", NUM2INT(rencoding));
     }
   }
 
   Data_Get_Struct(self, xmlDoc, xdoc);
-  xmlDocDumpFormatMemoryEnc(xdoc, &buffer, &length, xencoding, indent);
+  xmlDocDumpFormatMemoryEnc(xdoc, &buffer, &length, (const char*)xencoding, indent);
 
-  result = rxml_new_cstr((const char*) buffer, xencoding);
+  result = rxml_new_cstr(buffer, xencoding);
   xmlFree(buffer);
   return result;
 }
@@ -915,7 +901,7 @@ static VALUE rxml_document_url_get(VALUE self)
   if (xdoc->URL == NULL)
     return (Qnil);
   else
-    return (rxml_new_cstr((const char*) xdoc->URL, NULL));
+    return (rxml_new_cstr( xdoc->URL, NULL));
 }
 
 /*
@@ -932,7 +918,7 @@ static VALUE rxml_document_version_get(VALUE self)
   if (xdoc->version == NULL)
     return (Qnil);
   else
-    return (rxml_new_cstr((const char*) xdoc->version, NULL));
+    return (rxml_new_cstr( xdoc->version, NULL));
 }
 
 /*
