@@ -18,8 +18,8 @@ VALUE cXMLNode;
 /* Memory management:
  *
  * The bindings create a one-to-one mapping between libxml nodes
- * and Ruby nodes.  If a libxml node is wraped, its _private member
- * is set with a reference to the Ruby object.
+ * and Ruby nodes.  If a libxml node is wrapped, the mapping is stored in the
+ * private_pointers hashtable.
  *
  * When a libxml document or top level node is freed, it will free
  * all its children.  Thus Ruby is responsible for:
@@ -30,8 +30,8 @@ VALUE cXMLNode;
  *    standing nodes Ruby is referencing via the node or its children.
  *
  * In general use, this will cause Ruby nodes to be freed before
- * a libxml document.  When a Ruby node is freed, the _private
- * field is set back to null.  
+ * a libxml document.  When a Ruby node is freed, the hashtable entry is
+ * removed.
  *
  * In the sweep phase in Ruby 1.9.*, the document tends to be
  * freed before the nodes.  To support this, the bindings register
@@ -43,34 +43,31 @@ VALUE cXMLNode;
 static void rxml_node_deregisterNode(xmlNodePtr xnode)
 {
   /* Has the node been wrapped and exposed to Ruby? */
-  if (xnode->_private)
-  {
-    /* Node was wrapped.  Set the _private member to free and
-      then disable the dfree function so that Ruby will not
-      try to free the node a second time. */
-    VALUE node = (VALUE) xnode->_private;
-    RDATA(node)->data = NULL;
-    RDATA(node)->dfree = NULL;
-    RDATA(node)->dmark = NULL;
-  }
+  VALUE node = rxml_lookup_node(xnode);
+  if (node == Qnil)
+      return;
+
+  /* Node was wrapped. Disassociate the ruby object from the xml node
+     and turn off the free function so Ruby will not call it when the
+     wrapping object is itself freed. Note we still MUST include 
+     the mark function.  Unsetting it breaks the Ruby GC. */
+   RDATA(node)->dfree = NULL;
+   RDATA(node)->data = NULL;
+
+  // Remove the hashtable entry
+  rxml_unregister_node(xnode);
 }
 
 static void rxml_node_free(xmlNodePtr xnode)
 {
-  /* Either the node has been created yet in initialize
-     or it has been freed by libxml already in Ruby's 
-     mark phase. */
-  if (xnode == NULL)
-    return;
-
   /* The ruby object wrapping the xml object no longer exists. */
-  xnode->_private = NULL;
+  rxml_unregister_node(xnode);
 
   /* Ruby is responsible for freeing this node if it does not
      have a parent and is not owned by a document.  Note a corner
      case here - calling node2 = doc.import(node1) will cause node2
      to not have a parent but to have a document. */
-  if (xnode->parent == NULL)
+  if (xnode->doc == NULL && xnode->parent == NULL)
   {
     xmlFreeNode(xnode);
   }
@@ -78,32 +75,31 @@ static void rxml_node_free(xmlNodePtr xnode)
 
  void rxml_node_mark(xmlNodePtr xnode)
 {
-  /* Either the node has not been created yet in initialize
+   VALUE doc = Qnil;
+   VALUE parent = Qnil;
+
+   /* Either the node has not been created yet in initialize
      or it has been freed by libxml already in Ruby's 
      mark phase. */
   if (xnode == NULL)
     return;
 
-  if (xnode->doc && xnode->doc->_private)
-    rb_gc_mark((VALUE) xnode->doc->_private);
-  
-  if (xnode->parent && xnode->parent->_private)
-    rb_gc_mark((VALUE) xnode->_private);
+  doc = rxml_lookup_doc(xnode->doc);
+  if (doc != Qnil)
+    rb_gc_mark(doc);
+
+  parent = rxml_lookup_node(xnode->parent);
+  if (parent != Qnil)
+     rb_gc_mark(parent);
 }
 
 VALUE rxml_node_wrap(xmlNodePtr xnode)
 {
-  VALUE result;
+  VALUE result = rxml_lookup_node(xnode);
 
-  /* Is the node already wrapped? */
-  if (xnode->_private != NULL)
-  {
-    result = (VALUE) xnode->_private;
-  }
-  else
-  {
+  if (result == Qnil) {
     result = Data_Wrap_Struct(cXMLNode, rxml_node_mark, rxml_node_free, xnode);
-    xnode->_private = (void*) result;
+    rxml_register_node(xnode, result);
   }
   return result;
 }
@@ -147,8 +143,7 @@ static VALUE rxml_node_new_cdata(int argc, VALUE *argv, VALUE klass)
   else
   {
     content = rb_obj_as_string(content);
-    xnode = xmlNewCDataBlock(NULL, (xmlChar*) StringValuePtr(content),
-        RSTRING_LEN(content));
+    xnode = xmlNewCDataBlock(NULL, (xmlChar*) StringValuePtr(content), (int)RSTRING_LEN(content));
   }
 
   if (xnode == NULL)
@@ -276,7 +271,7 @@ static VALUE rxml_node_initialize(int argc, VALUE *argv, VALUE self)
     rxml_raise(&xmlLastError);
 
   /* Link the Ruby object to the libxml object and vice-versa. */
-  xnode->_private = (void*) self;
+  rxml_register_node(xnode, self);
   DATA_PTR(self) = xnode;
 
   if (!NIL_P(content))
@@ -311,7 +306,7 @@ static VALUE rxml_node_modify_dom(VALUE self, VALUE target,
   if (xresult != xtarget)
   {
     RDATA(target)->data = xresult;
-    xresult->_private = (void*) target;
+    rxml_register_node(xresult, target);
   }
 
   return target;
@@ -337,7 +332,7 @@ static VALUE rxml_node_base_uri_get(VALUE self)
   base_uri = xmlNodeGetBase(xnode->doc, xnode);
   if (base_uri)
   {
-    result = rxml_new_cstr((const char*) base_uri, NULL);
+    result = rxml_new_cstr( base_uri, NULL);
     xmlFree(base_uri);
   }
 
@@ -381,7 +376,7 @@ static VALUE rxml_node_content_get(VALUE self)
   content = xmlNodeGetContent(xnode);
   if (content)
   {
-    result = rxml_new_cstr((const char *) content, NULL);
+    result = rxml_new_cstr(content, NULL);
     xmlFree(content);
   }
 
@@ -403,6 +398,7 @@ static VALUE rxml_node_content_set(VALUE self, VALUE content)
   xnode = rxml_get_xnode(self);
   encoded_content = xmlEncodeSpecialChars(xnode->doc, (xmlChar*) StringValuePtr(content));
   xmlNodeSetContent(xnode, encoded_content);
+  xmlFree(encoded_content);
   return (Qtrue);
 }
 
@@ -429,7 +425,7 @@ static VALUE rxml_node_content_stripped_get(VALUE self)
   content = xmlNodeGetContent(xnode);
   if (content)
   {
-    result = rxml_new_cstr((const char*) content, NULL);
+    result = rxml_new_cstr( content, NULL);
     xmlFree(content);
   }
   return (result);
@@ -543,10 +539,8 @@ static VALUE rxml_node_doc(VALUE self)
 
   if (xdoc == NULL)
     return (Qnil);
-  else if (xdoc->_private)
-    return (VALUE) xdoc->_private;
-  else
-    return (Qnil);
+
+  return rxml_lookup_doc(xdoc);
 }
 
 /*
@@ -585,7 +579,7 @@ static VALUE rxml_node_to_s(int argc, VALUE *argv, VALUE self)
 
   int level = 0;
   int indent = 1;
-  const char *xencoding = "UTF-8";
+  const xmlChar *xencoding = (const xmlChar*)"UTF-8";
 
   rb_scan_args(argc, argv, "01", &options);
 
@@ -605,30 +599,30 @@ static VALUE rxml_node_to_s(int argc, VALUE *argv, VALUE self)
 
     if (rencoding != Qnil)
     {
-      xencoding = xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
+      xencoding = (const xmlChar*)xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
       if (!xencoding)
         rb_raise(rb_eArgError, "Unknown encoding value: %d", NUM2INT(rencoding));
     }
   }
 
-  encodingHandler = xmlFindCharEncodingHandler(xencoding);
+  encodingHandler = xmlFindCharEncodingHandler((const char*)xencoding);
   output = xmlAllocOutputBuffer(encodingHandler);
 
   xnode = rxml_get_xnode(self);
 
-  xmlNodeDumpOutput(output, xnode->doc, xnode, level, indent, xencoding);
+  xmlNodeDumpOutput(output, xnode->doc, xnode, level, indent, (const char*)xencoding);
   xmlOutputBufferFlush(output);
 
 #ifdef LIBXML2_NEW_BUFFER
   if (output->conv)
-    result = rxml_new_cstr((const char*) xmlBufContent(output->conv), xencoding);
+    result = rxml_new_cstr(xmlBufContent(output->conv), xencoding);
   else
-    result = rxml_new_cstr((const char*) xmlBufContent(output->buffer), xencoding);
+    result = rxml_new_cstr(xmlBufContent(output->buffer), xencoding);
 #else
   if (output->conv)
-    result = rxml_new_cstr((const char*) output->conv->content, xencoding);
+    result = rxml_new_cstr(xmlBufferContent(output->conv), xencoding);
   else
-    result = rxml_new_cstr((const char*) output->buffer->content, xencoding);
+    result = rxml_new_cstr(xmlBufferContent(output->buffer), xencoding);
 #endif
 
   xmlOutputBufferClose(output);
@@ -733,7 +727,7 @@ static VALUE rxml_node_lang_get(VALUE self)
 
   if (lang)
   {
-    result = rxml_new_cstr((const char*) lang, NULL);
+    result = rxml_new_cstr( lang, NULL);
     xmlFree(lang);
   }
 
@@ -866,11 +860,11 @@ static VALUE rxml_node_xlink_type_name(VALUE self)
   case XLINK_TYPE_NONE:
     return (Qnil);
   case XLINK_TYPE_SIMPLE:
-    return (rxml_new_cstr("simple", NULL));
+    return (rxml_new_cstr((const xmlChar*)"simple", NULL));
   case XLINK_TYPE_EXTENDED:
-    return (rxml_new_cstr("extended", NULL));
+    return (rxml_new_cstr((const xmlChar*)"extended", NULL));
   case XLINK_TYPE_EXTENDED_SET:
-    return (rxml_new_cstr("extended_set", NULL));
+    return (rxml_new_cstr((const xmlChar*)"extended_set", NULL));
   default:
     rb_fatal("Unknowng xlink type, %d", xlt);
   }
@@ -921,7 +915,7 @@ static VALUE rxml_node_name_get(VALUE self)
   if (xnode->name == NULL)
     return (Qnil);
   else
-    return (rxml_new_cstr((const char*) name, NULL));
+    return (rxml_new_cstr( name, NULL));
 }
 
 /*
@@ -1013,7 +1007,7 @@ static VALUE rxml_node_path(VALUE self)
   if (path == NULL)
     return (Qnil);
   else
-    return (rxml_new_cstr((const char*) path, NULL));
+    return (rxml_new_cstr( path, NULL));
 }
 
 /*
@@ -1146,17 +1140,17 @@ static VALUE rxml_node_remove_ex(VALUE self)
   xresult = xmlDocCopyNode(xnode, NULL, 1);
 
   /* This ruby node object no longer points at the node.*/
-  xnode->_private = NULL;
+  rxml_unregister_node(xnode);
   RDATA(self)->data = NULL;
 
   /* Now free the original node.  This will call the deregister node
-    callback which would reset the mark and free function except for 
-	the fact we set the _private field to null above*/
+    callback which would reset the mark and free function except for
+	the fact we already removed it from the private hashtable above */
   xmlFreeNode(xnode);
 
   /* Now wrap the new node */
   RDATA(self)->data = xresult;
-  xresult->_private = (void*) self;
+  rxml_register_node(xresult, self);
 
   /* Now return the removed node so the user can
      do something with it.*/
@@ -1242,19 +1236,19 @@ static VALUE rxml_node_output_escaping_q(VALUE self)
  * Text nodes which are added to an element or attribute node will be affected
  * by any previous setting of this property.
  */
-static VALUE rxml_node_output_escaping_set(VALUE self, VALUE bool)
+static VALUE rxml_node_output_escaping_set(VALUE self, VALUE value)
 {
   xmlNodePtr xnode;
   xnode = rxml_get_xnode(self);
 
   switch (xnode->type) {
   case XML_TEXT_NODE:
-    xnode->name = (bool!=Qfalse && bool!=Qnil) ? xmlStringText : xmlStringTextNoenc;
+    xnode->name = (value != Qfalse && value != Qnil) ? xmlStringText : xmlStringTextNoenc;
     break;
   case XML_ELEMENT_NODE:
   case XML_ATTRIBUTE_NODE:
     {
-      const xmlChar *name = (bool!=Qfalse && bool!=Qnil) ? xmlStringText : xmlStringTextNoenc;
+      const xmlChar *name = (value != Qfalse && value != Qnil) ? xmlStringText : xmlStringTextNoenc;
       xmlNodePtr tmp;
       for (tmp = xnode->children; tmp; tmp = tmp->next)
         if (tmp->type == XML_TEXT_NODE)
@@ -1265,7 +1259,7 @@ static VALUE rxml_node_output_escaping_set(VALUE self, VALUE bool)
     return Qnil;
   }
 
-  return (bool!=Qfalse && bool!=Qnil) ? Qtrue : Qfalse;
+  return (value!=Qfalse && value!=Qnil) ? Qtrue : Qfalse;
 }
 
 /*
@@ -1288,12 +1282,12 @@ static VALUE rxml_node_space_preserve_get(VALUE self)
  *
  * Control whether this node preserves whitespace.
  */
-static VALUE rxml_node_space_preserve_set(VALUE self, VALUE bool)
+static VALUE rxml_node_space_preserve_set(VALUE self, VALUE value)
 {
   xmlNodePtr xnode;
   xnode = rxml_get_xnode(self);
 
-  if (TYPE(bool) == T_FALSE)
+  if (value == Qfalse)
     xmlNodeSetSpacePreserve(xnode, 0);
   else
     xmlNodeSetSpacePreserve(xnode, 1);
