@@ -62,9 +62,8 @@ static void rxml_reader_free(xmlTextReaderPtr xreader)
 static void rxml_reader_mark(xmlTextReaderPtr xreader)
 {
   xmlDocPtr xdoc = xmlTextReaderCurrentDoc(xreader);
-
-  if (xdoc && xdoc->_private)
-    rb_gc_mark((VALUE) xdoc->_private);
+  VALUE value = rxml_lookup_doc(xdoc);
+  rb_gc_mark(value);
 }
 
 static VALUE rxml_reader_wrap(xmlTextReaderPtr xreader)
@@ -263,7 +262,7 @@ static VALUE rxml_reader_string(int argc, VALUE *argv, VALUE klass)
     xoptions = NIL_P(parserOptions) ? 0 : NUM2INT(parserOptions);
   }
   
-  xreader = xmlReaderForMemory(StringValueCStr(string), RSTRING_LEN(string), 
+  xreader = xmlReaderForMemory(StringValueCStr(string), (int)RSTRING_LEN(string),
                                xbaseurl, xencoding, xoptions);
 
   if (xreader == NULL)
@@ -528,7 +527,7 @@ static VALUE rxml_reader_read_inner_xml(VALUE self)
   if (xml)
   {
     const xmlChar *xencoding = xmlTextReaderConstEncoding(xReader);
-    result = rxml_new_cstr((const char*) xml, xencoding);
+    result = rxml_new_cstr( xml, xencoding);
     xmlFree(xml);
   }
 
@@ -554,7 +553,7 @@ static VALUE rxml_reader_read_outer_xml(VALUE self)
   if (xml)
   {
     const xmlChar *xencoding = xmlTextReaderConstEncoding(xReader);
-    result = rxml_new_cstr((const char*) xml, xencoding);
+    result = rxml_new_cstr( xml, xencoding);
     xmlFree(xml);
   }
 
@@ -592,7 +591,7 @@ static VALUE rxml_reader_read_string(VALUE self)
   if (xml)
   {
     const xmlChar *xencoding = xmlTextReaderConstEncoding(xReader);
-    result = rxml_new_cstr((const char*) xml, xencoding);
+    result = rxml_new_cstr( xml, xencoding);
     xmlFree(xml);
   }
 
@@ -709,7 +708,7 @@ static VALUE rxml_reader_encoding(VALUE self)
   xmlTextReaderPtr xreader = rxml_text_reader_get(self);
   const xmlChar *xencoding = xmlTextReaderConstEncoding(xreader);
   if (xencoding)
-    return INT2NUM(xmlParseCharEncoding(xencoding));
+    return INT2NUM(xmlParseCharEncoding((const char*)xencoding));
   else
     return INT2NUM(XML_CHAR_ENCODING_NONE);
 }
@@ -915,8 +914,7 @@ static VALUE rxml_reader_get_attribute(VALUE self, VALUE name)
   xmlTextReaderPtr xReader = rxml_text_reader_get(self);
   const xmlChar *xencoding = xmlTextReaderConstEncoding(xReader);
 
-  xattr = xmlTextReaderGetAttribute(xReader,
-    (const xmlChar *) StringValueCStr(name));
+  xattr = xmlTextReaderGetAttribute(xReader, (const xmlChar *) StringValueCStr(name));
   if (xattr)
   {
     result = rxml_new_cstr(xattr, xencoding);
@@ -982,7 +980,7 @@ static VALUE rxml_reader_lookup_namespace(VALUE self, VALUE prefix)
 
   if (xnamespace)
   {
-    result = rxml_new_cstr((const char*)xnamespace, (const char*)xencoding);
+    result = rxml_new_cstr(xnamespace, xencoding);
     xmlFree((void *)xnamespace);
   }
   return result;
