@@ -105,7 +105,7 @@ rxml_xpath_to_value(xmlXPathContextPtr xctxt, xmlXPathObjectPtr xobject) {
       xmlXPathFreeObject(xobject);
       break;
     case XPATH_STRING:
-      result = rxml_new_cstr((const char*)xobject->stringval, xctxt->doc->encoding);
+      result = rxml_new_cstr(xobject->stringval, xctxt->doc->encoding);
       xmlXPathFreeObject(xobject);
       break;
     default:
@@ -138,7 +138,7 @@ rxml_xpath_from_value(VALUE value) {
       result = xmlXPathNewNodeSet(NULL);
       break;
     case T_ARRAY: {
-      int i, j;
+      long i, j;
       result = xmlXPathNewNodeSet(NULL);
 
       for (i = RARRAY_LEN(value); i > 0; i--) {
