@@ -50,9 +50,9 @@ static void rxml_xpath_namespace_free(xmlNsPtr xns)
 
 static void rxml_xpath_object_mark(rxml_xpath_object *rxpop)
 {
+  VALUE doc = rxml_lookup_doc(rxpop->xdoc);
+  rb_gc_mark(doc);
   rb_gc_mark(rxpop->nsnodes);
-  if (rxpop->xdoc->_private)
-    rb_gc_mark((VALUE)rxpop->xdoc->_private);
 }
 
 VALUE rxml_xpath_object_wrap(xmlDocPtr xdoc, xmlXPathObjectPtr xpop)
@@ -294,7 +294,7 @@ static VALUE rxml_xpath_object_string(VALUE self)
   if (rxpop->xpop->stringval == NULL)
     return Qnil;
 
-  return rxml_new_cstr((const char*) rxpop->xpop->stringval, rxpop->xdoc->encoding);
+  return rxml_new_cstr( rxpop->xpop->stringval, rxpop->xdoc->encoding);
 }
 
 /*
