@@ -1,10 +1,9 @@
 # encoding: UTF-8
 
 require './test_helper'
-require 'test/unit'
 require 'stringio'
 
-class TestError < Test::Unit::TestCase
+class TestError < Minitest::Test
   def test_error_codes
     assert_equal(4, XML::Error::DTD)
     assert_equal(4, XML::Error.const_get('DTD'))
@@ -14,7 +13,7 @@ class TestError < Test::Unit::TestCase
   end
 
   def test_invalid_handler
-    assert_raise(RuntimeError) do
+    assert_raises(RuntimeError) do
       XML::Error.set_handler
     end
   end
@@ -26,13 +25,13 @@ class TestError < Test::Unit::TestCase
     end
 
     # Raise the error
-    error = assert_raise(XML::Error) do
+    error = assert_raises(XML::Error) do
       XML::Reader.string('<foo').read
     end
     assert_equal(exception, error)
 
     # Check the handler worked
-    assert_not_nil(exception)
+    refute_nil(exception)
     assert_kind_of(XML::Error, exception)
     assert_equal("Fatal error: Couldn't find end of Start Tag foo at :1.", exception.message)
     assert_equal(XML::Error::PARSER, exception.domain)
@@ -65,7 +64,7 @@ class TestError < Test::Unit::TestCase
 
     saved_handler = XML::Error.get_handler
     XML::Error.set_handler{ puts "New handler" }
-    assert_not_equal(XML::Error.get_handler, saved_handler)
+    refute_equal(XML::Error.get_handler, saved_handler)
 
     XML::Error.set_handler(&saved_handler)
     assert_equal(XML::Error.get_handler, saved_handler)
@@ -78,7 +77,7 @@ class TestError < Test::Unit::TestCase
 
     Object.const_set(:STDERR, output)
     begin
-      assert_raise(XML::Error) do
+      assert_raises(XML::Error) do
         XML::Parser.string('<foo><bar/></foz>').parse
       end
     ensure
@@ -94,7 +93,7 @@ class TestError < Test::Unit::TestCase
 
     Object.const_set(:STDERR, output)
     begin
-      assert_raise(XML::Error) do
+      assert_raises(XML::Error) do
         XML::Parser.string('<foo><bar/></foz>').parse
       end
     ensure
@@ -104,7 +103,7 @@ class TestError < Test::Unit::TestCase
   end
 
   def test_parse_error
-    exception = assert_raise(XML::Error) do
+    exception = assert_raises(XML::Error) do
       XML::Parser.string('<foo><bar/></foz>').parse
     end
 
@@ -120,7 +119,7 @@ class TestError < Test::Unit::TestCase
   def test_xpath_error
     doc = XML::Document.file(File.join(File.dirname(__FILE__), 'model/soap.xml'))
 
-    exception = assert_raise(XML::Error) do
+    exception = assert_raises(XML::Error) do
       doc.find('/foo[bar=test')
     end
 
@@ -138,7 +137,7 @@ class TestError < Test::Unit::TestCase
     parser = XML::Parser.string("<test>something</test>")
     parser.parse
 
-    error = assert_raise(XML::Error) do
+    error = assert_raises(XML::Error) do
       # Try parsing a second time
       parser.parse
     end
@@ -149,19 +148,19 @@ class TestError < Test::Unit::TestCase
   def test_libxml_parser_empty_string
     xp = XML::Parser.new
 
-    error = assert_raise(TypeError) do
+    error = assert_raises(TypeError) do
       xp.string = nil
     end
     assert_equal('wrong argument type nil (expected String)', error.to_s)
 
-    error = assert_raise(ArgumentError) do
+    error = assert_raises(ArgumentError) do
       xp.string = ''
     end
     assert_equal('Must specify a string with one or more characters', error.to_s)
   end
 
   def test_error_domain_to_s
-    exception = assert_raise(XML::Error) do
+    exception = assert_raises(XML::Error) do
       XML::Parser.string('<foo href="http://example.org/cgi?k1=v1&k2=v2"></foo>').parse
     end
 
@@ -170,7 +169,7 @@ class TestError < Test::Unit::TestCase
   end
 
   def test_error_code_to_s
-    exception = assert_raise(XML::Error) do
+    exception = assert_raises(XML::Error) do
       XML::Parser.string('<foo href="http://example.org/cgi?k1=v1&k2=v2"></foo>').parse
     end
     assert_equal(XML::Error::ENTITYREF_SEMICOL_MISSING, exception.code)
