@@ -1,20 +1,13 @@
 # encoding: UTF-8
 
 require './test_helper'
-require 'test/unit'
 require 'stringio'
 
-class TestParser < Test::Unit::TestCase
+class TestParser < Minitest::Test
   def setup
     XML::Error.set_handler(&XML::Error::QUIET_HANDLER)
   end
 
-  def teardown
-    GC.start
-    GC.start
-    GC.start
-  end
-      
   # -----  Sources  -------
   def test_document
     file = File.expand_path(File.join(File.dirname(__FILE__), 'model/bands.utf-8.xml'))
@@ -30,7 +23,7 @@ class TestParser < Test::Unit::TestCase
   end
 
   def test_nil_document
-    error = assert_raise(TypeError) do
+    error = assert_raises(TypeError) do
       XML::Parser.document(nil)
     end
 
@@ -47,7 +40,7 @@ class TestParser < Test::Unit::TestCase
   end
 
   def test_noexistent_file
-    error = assert_raise(XML::Error) do
+    error = assert_raises(XML::Error) do
       XML::Parser.file('i_dont_exist.xml')
     end
 
@@ -55,7 +48,7 @@ class TestParser < Test::Unit::TestCase
   end
 
   def test_nil_file
-    error = assert_raise(TypeError) do
+    error = assert_raises(TypeError) do
       XML::Parser.file(nil)
     end
 
@@ -66,7 +59,7 @@ class TestParser < Test::Unit::TestCase
     file = File.expand_path(File.join(File.dirname(__FILE__), 'model/bands.utf-8.xml'))
     parser = XML::Parser.file(file, :encoding => XML::Encoding::ISO_8859_1)
 
-    error = assert_raise(XML::Error) do
+    error = assert_raises(XML::Error) do
       doc = parser.parse
     end
 
@@ -74,7 +67,7 @@ class TestParser < Test::Unit::TestCase
 
     parser = XML::Parser.file(file, :encoding => XML::Encoding::UTF_8)
     doc = parser.parse
-    assert_not_nil(doc)
+    refute_nil(doc)
   end
 
   def test_file_base_uri
@@ -111,7 +104,7 @@ class TestParser < Test::Unit::TestCase
   end
 
   def test_nil_io
-    error = assert_raise(TypeError) do
+    error = assert_raises(TypeError) do
       XML::Parser.io(nil)
     end
 
@@ -141,8 +134,9 @@ class TestParser < Test::Unit::TestCase
 
     thread.join
     assert(true)
+    puts 'Thread completed'
   end
-  
+
   def test_string
     str = '<ruby_array uga="booga" foo="bar"><fixnum>one</fixnum><fixnum>two</fixnum></ruby_array>'
 
@@ -155,7 +149,7 @@ class TestParser < Test::Unit::TestCase
   end
 
   def test_nil_string
-    error = assert_raise(TypeError) do
+    error = assert_raises(TypeError) do
       XML::Parser.string(nil)
     end
 
@@ -215,7 +209,7 @@ class TestParser < Test::Unit::TestCase
     # Parse as UTF_8
     parser = XML::Parser.string(xml, :encoding => XML::Encoding::UTF_8)
 
-    error = assert_raise(XML::Error) do
+    error = assert_raises(XML::Error) do
       doc = parser.parse
     end
 
@@ -246,7 +240,7 @@ class TestParser < Test::Unit::TestCase
     max_fd = if RUBY_PLATFORM.match(/mswin32|mingw/i)
       500
     else
-      (`ulimit -n`.chomp.to_i) + 1
+      Process.getrlimit(Process::RLIMIT_NOFILE)[0] + 1
     end
 
     file = File.join(File.dirname(__FILE__), 'model/rubynet.xml')
@@ -264,11 +258,11 @@ class TestParser < Test::Unit::TestCase
 
   # -----  Errors  ------
   def test_error
-    error = assert_raise(XML::Error) do
+    error = assert_raises(XML::Error) do
       XML::Parser.string('<foo><bar/></foz>').parse
     end
 
-    assert_not_nil(error)
+    refute_nil(error)
     assert_kind_of(XML::Error, error)
     assert_equal("Fatal error: Opening and ending tag mismatch: foo line 1 and foz at :1.", error.message)
     assert_equal(XML::Error::PARSER, error.domain)
@@ -286,11 +280,11 @@ class TestParser < Test::Unit::TestCase
 
   def test_bad_xml
     parser = XML::Parser.string('<ruby_array uga="booga" foo="bar"<fixnum>one</fixnum><fixnum>two</fixnum></ruby_array>')
-    error = assert_raise(XML::Error) do
-      assert_not_nil(parser.parse)
+    error = assert_raises(XML::Error) do
+      refute_nil(parser.parse)
     end
 
-    assert_not_nil(error)
+    refute_nil(error)
     assert_kind_of(XML::Error, error)
     assert_equal("Fatal error: Extra content at the end of the document at :1.", error.message)
     assert_equal(XML::Error::PARSER, error.domain)
@@ -302,7 +296,7 @@ class TestParser < Test::Unit::TestCase
     assert_nil(error.str2)
     assert_nil(error.str3)
     assert_equal(0, error.int1)
-    assert_equal(20, error.int2)
+    assert_equal(34, error.int2)
     assert_nil(error.node)
   end
 
