@@ -11,4 +11,6 @@ $LOAD_PATH << lib
 $LOAD_PATH << ext
 
 require 'xml'
-
+require 'minitest/autorun'
+# require 'minitest/reporters'
+# MiniTest::Reporters.use!
\ No newline at end of file
